@@ -1,4 +1,4 @@
-#include "distances-details.h"
+#include "details.h"
 
 #include <algorithm> // std::max
 #include <math.h> // exp, log, pow
@@ -6,6 +6,7 @@
 #include <R.h> // R_PosInf
 
 #include "../utils/SurrogateMatrix.h"
+#include "../utils/utils.h" // id_t
 
 namespace dtwclust {
 
@@ -13,13 +14,13 @@ namespace dtwclust {
 /* point-wise squared Euclidean norm */
 // =================================================================================================
 
-double squared_euclidean(const double * const x, const double * const y,
-                         const int i, const int j,
-                         const int x_nrows, const int y_nrows, const int ncols)
+double squared_euclidean(const SurrogateMatrix<const double>& x,
+                         const SurrogateMatrix<const double>& y,
+                         const id_t i, const id_t j)
 {
     double d = 0;
-    for (int k = 0; k < ncols; k++)
-        d += pow(x[i + k * x_nrows] - y[j + k * y_nrows], 2);
+    for (id_t k = 0; k < x.ncol(); k++)
+        d += pow(x(i,k) - y(j,k), 2);
     return d;
 }
 
@@ -44,45 +45,30 @@ double soft_min(double a, double b, double c, const double gamma)
 /* thread-safe versions for the distance calculator */
 // =================================================================================================
 
-double sdtw(const double * const x, const double * const y,
-            const int nx, const int ny, const int num_vars,
+double sdtw(const SurrogateMatrix<const double>& x, const SurrogateMatrix<const double>& y,
             const double gamma, SurrogateMatrix<double>& costmat)
 {
-    // initialize costmat values
-    costmat[0] = 0;
-    for (int i = 1; i < nx+2; i++) costmat(i,0) = R_PosInf;
-    for (int j = 1; j < ny+2; j++) costmat(0,j) = R_PosInf;
-    // compute distance
-    for (int i = 1; i <= nx; i++) {
-        for (int j = 1; j <= ny; j++) {
-            double point_norm = squared_euclidean(x, y, i-1, j-1, nx, ny, num_vars);
-            costmat(i,j) = point_norm + soft_min(costmat(i-1,j),
-                                                 costmat(i-1,j-1),
-                                                 costmat(i,j-1),
-                                                 gamma);
-        }
-    }
-    return costmat(nx,ny);
+    SurrogateMatrix<double> dummy_distmat;
+    return sdtw(x, y, gamma, costmat, dummy_distmat);
 }
 
-double sdtw(const double * const x, const double * const y,
-            const int nx, const int ny, const int num_vars,
-            const double gamma, SurrogateMatrix<double>& costmat,
-            SurrogateMatrix<double>& distmat)
+double sdtw(const SurrogateMatrix<const double>& x, const SurrogateMatrix<const double>& y,
+            const double gamma, SurrogateMatrix<double>& costmat, SurrogateMatrix<double>& distmat)
 {
+    id_t nx = x.nrow(), ny = y.nrow();
     // initialize costmat values
     costmat[0] = 0;
-    for (int i = 1; i < nx+2; i++) costmat(i,0) = R_PosInf;
-    for (int j = 1; j < ny+2; j++) costmat(0,j) = R_PosInf;
+    for (id_t i = 1; i < nx+2; i++) costmat(i,0) = R_PosInf;
+    for (id_t j = 1; j < ny+2; j++) costmat(0,j) = R_PosInf;
     // compute distance
-    for (int i = 1; i <= nx; i++) {
-        for (int j = 1; j <= ny; j++) {
-            double point_norm = squared_euclidean(x, y, i-1, j-1, nx, ny, num_vars);
+    for (id_t i = 1; i <= nx; i++) {
+        for (id_t j = 1; j <= ny; j++) {
+            double point_norm = squared_euclidean(x, y, i-1, j-1);
             costmat(i,j) = point_norm + soft_min(costmat(i-1,j),
                                                  costmat(i-1,j-1),
                                                  costmat(i,j-1),
                                                  gamma);
-            distmat(i-1,j-1) = point_norm;
+            if (distmat) distmat(i-1,j-1) = point_norm;
         }
     }
     return costmat(nx,ny);
