@@ -2,6 +2,11 @@ library(dtwclust)
 library(foreach)
 library(testthat)
 
+# coverage for multi-threading might not be possible (?)
+if (nzchar(Sys.getenv("R_COVR"))) RcppParallel::setThreadOptions(1L)
+# old reporter for CMD checks
+options(testthat.default_reporter = "summary")
+
 #' To test in a local machine:
 #' Sys.setenv(NOT_CRAN = "true"); test_dir("tests/testthat/")
 #' OR
