@@ -1,4 +1,4 @@
-context("\tSymmetric GAK")
+context("    Symmetric GAK")
 
 # ==================================================================================================
 # setup
