@@ -23,10 +23,13 @@ with(persistent, {
         expect_known_value(cent_mv_shape, file_name(cent_mv_shape), info = "Multivariate")
         expect_known_value(cent_pam, file_name(cent_pam), info = "Univariate without distmat")
         expect_known_value(cent_mv_pam, file_name(cent_mv_pam), info = "Multivariate")
-        expect_known_value(cent_dba, file_name(cent_dba, x32 = TRUE), info = "Univariate")
-        expect_known_value(cent_mv_dba, file_name(cent_mv_dba, x32 = TRUE), info = "Multivariate")
+
+        tol <- if (.Machine$sizeof.pointer == 4L) 1e-2 else sqrt(.Machine$double.eps)
+        expect_known_value(cent_dba, file_name(cent_dba, x32 = TRUE), tolerance = tol, info = "Univariate")
+        expect_known_value(cent_mv_dba, file_name(cent_mv_dba, x32 = TRUE), tolerance = tol, info = "Multivariate")
+
         expect_known_value(cent_mv_dba_bys, file_name(cent_mv_dba_bys), info = "DBA by series")
-        expect_known_value(cent_sdtwc, file_name(cent_sdtwc), info = "SDTWC Univariate")
+        expect_known_value(cent_sdtwc, file_name(cent_sdtwc), tolerance = 1e-6, info = "SDTWC Univariate")
         expect_known_value(cent_mv_sdtwc, file_name(cent_mv_sdtwc), info = "SDTWC Multivariate")
     })
 })
